library(testthat)
library(rPackedBar)  # nolint

test_check("rPackedBar")
